@@ -7,7 +7,7 @@
 import numpy as np
 
 from .cysoxr import CySoxr
-from .cysoxr import cysoxr_divide_proc_1d, cysoxr_divide_proc_2d
+from .cysoxr import cysoxr_divide_proc
 from .cysoxr import cysoxr_oneshot
 from .cysoxr import QQ, LQ, MQ, HQ, VHQ
 
@@ -46,10 +46,7 @@ def _quality_to_enum(q):
 
 
 class ResampleStream():
-    def __init__(self,
-                 in_rate: float, out_rate: float, num_channels: int,
-                 dtype=np.float32, quality=HQ):
-        ''' Streaming resampler
+    ''' Streaming resampler
 
         Use `ResampleStream` for real-time processing or very long signal.
 
@@ -64,11 +61,14 @@ class ResampleStream():
         dtype : type or str, optional
             Internal data type processed with.
             Should be one of float32, float64, int16, int32.
-            The default is np.float32.
         quality : int or str, optional
             Quality setting.
-            One of `QQ`, `LQ`, `MQ`, `HQ`, `VHQ`. The default is HQ.
-        '''
+            One of `QQ`, `LQ`, `MQ`, `HQ`, `VHQ`.
+    '''
+
+    def __init__(self,
+                 in_rate: float, out_rate: float, num_channels: int,
+                 dtype='float32', quality='HQ'):
         if in_rate <= 0 or out_rate <= 0:
             raise ValueError('Sample rate should be over 0')
 
@@ -93,8 +93,8 @@ class ResampleStream():
         ----------
         x : array_like
             Input array. Input can be 1D(mono) or 2D(frames, channels).
-            If input is not np.ndarray or not dtype in constructor,
-            it will be converted to np.ndarray with dtype setting.
+            If input is not `np.ndarray` or not dtype in constructor,
+            it will be converted to `np.ndarray` with dtype setting.
 
         last : bool, optional
             Set True at end of input sequence.
@@ -109,17 +109,25 @@ class ResampleStream():
         if type(x) != np.ndarray or x.dtype.type != self._type:
             x = np.asarray(x, dtype=self._type)
 
-        return self._cysoxr.process(x, last)
+        x = np.ascontiguousarray(x)    # make array C-contiguous
+
+        if x.ndim == 1:
+            y = self._cysoxr.process(x[:, np.newaxis], last)
+            return np.squeeze(y, axis=1)
+        elif x.ndim == 2:
+            return self._cysoxr.process(x, last)
+        else:
+            raise ValueError('Input must be 1-D or 2-D array')
 
 
-def resample(x, in_rate: float, out_rate: float, quality=HQ):
+def resample(x, in_rate: float, out_rate: float, quality='HQ'):
     """ Resample signal
 
     Parameters
     ----------
     x : array_like
         Input array. Input can be 1D(mono) or 2D(frames, channels).
-        If input is not np.ndarray, it will be converted to np.ndarray(dtype=np.float32)
+        If input is not `np.ndarray`, it will be converted to `np.ndarray(dtype='float32')`.
         Its dtype should be one of float32, float64, int16, int32.
     in_rate : float
         Input sample-rate.
@@ -127,13 +135,13 @@ def resample(x, in_rate: float, out_rate: float, quality=HQ):
         Output sample-rate.
     quality : int or str, optional
         Quality setting.
-        One of `QQ`, `LQ`, `MQ`, `HQ`, `VHQ`. The default is HQ.
+        One of `QQ`, `LQ`, `MQ`, `HQ`, `VHQ`.
 
     Returns
     -------
     np.ndarray
         Resampled data.
-        Output is np.ndarray with same ndim and dtype with input.
+        Output is `np.ndarray` with same ndim and dtype with input.
     """
     if in_rate <= 0 or out_rate <= 0:
         raise ValueError('Sample rate should be over 0')
@@ -149,21 +157,22 @@ def resample(x, in_rate: float, out_rate: float, quality=HQ):
     x = np.ascontiguousarray(x)    # make array C-contiguous
 
     if x.ndim == 1:
-        return cysoxr_divide_proc_1d(in_rate, out_rate, x, q)
+        y = cysoxr_divide_proc(in_rate, out_rate, x[:, np.newaxis], q)
+        return np.squeeze(y, axis=1)
     elif x.ndim == 2:
         num_channels = x.shape[1]
         if num_channels < 1 or _CH_LIMIT < num_channels:
             raise ValueError(_CH_EXEED_ERR_STR.format(num_channels))
 
-        return cysoxr_divide_proc_2d(in_rate, out_rate, x, q)
+        return cysoxr_divide_proc(in_rate, out_rate, x, q)
     else:
         raise ValueError('Input must be 1-D or 2-D array')
 
 
-def _resample_oneshot(x, in_rate: float, out_rate: float, quality=HQ):
+def _resample_oneshot(x, in_rate: float, out_rate: float, quality='HQ'):
     '''
     Resample using libsoxr's `soxr_oneshot()`. Use `resample()` for general use.
     `soxr_oneshot()` becomes slow with long input.
     This function exists for test purpose.
     '''
-    return cysoxr_oneshot(in_rate, out_rate, x, q=_quality_to_enum(quality))
+    return cysoxr_oneshot(in_rate, out_rate, x, _quality_to_enum(quality))
